<?php
/**
 * @version     $Id: helper.php 433 2010-04-06 19:57:59Z martin $
 * @package     Joomla
 * @subpackage  mmSlideShow - Free
 * @author      Martin Gray <author [at] mmPlugins.com>
 * @copyright   Copyright (C) 2009 mmPlugins | All rights reserved
 * @license     GNU/GPL v.2
 * @see         /modules/mod_mmslideshow/LICENSE.php
 */

// No direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.filesystem.folder');

class Mod_MMSlideshow_Helper
{
    /**
     * Fetches images form the designated directory
     *
     * @param string $path
     * @return array
     */
    function GetImages( $path )
    {
        // only grab jpg, gif & png
        $fullpath = JPATH_ROOT.$path;
        $files = JFolder::files( $fullpath, '.(.jpg)|(.gif)|(.png)|(.JPG)|(.GIF)|(.PNG)|(.jpeg)|(.JPEG)', false, true );
        return $files;
    }

    /**
     * Adds required JavaScript and CSS to the head tag through the Joomla API
     *
     * @param integer $module Module instance id
     * @param object $params
     * @param array $images The images as pulled from the nominated directory
     */
    function InitMMSlideshow( $module, $params, $images )
    {
        // Prepare module parameters
        $skin                   = $params->get( 'skin', 'mmaster' );
        $color                  = $params->get( 'color', 'blue' );
        $slideshow_width        = $params->get( 'slideshow_width', 450 );
        $slideshow_height       = $params->get( 'slideshow_height', 300 );
        $animation_type         = $params->get( 'animation_type', 'scroll' );
        $animation_direction    = $params->get( 'animation_direction', 'left' );
        $animation_transition   = $params->get( 'animation_transition', 'linear' );
        $animation_ease         = $params->get( 'animation_ease', 'easeInOut' );
        $animation_duration     = $params->get( 'animation_duration', 500 );
        $rotate_type            = $params->get( 'rotate_type', 'auto' );
        $rotate_interval        = $params->get( 'rotate_interval', 5000 );
        $rotate_onmouseover     = $params->get( 'rotate_onmouseover', 'stop' );
        $show_playpause         = $params->get( 'show_playpause', 1 );
        $show_previousnext      = $params->get( 'show_previousnext', 1 );

        // Get JDocument reference
        $document =& JFactory::getDocument();

        // Include css if requested
        if ( $params->get( 'include_css', 1 ) ):
            // Get basic skin CSS
            JHTML::stylesheet( 'skin.css', 'modules/mod_mmslideshow/skins/'.$skin.'/css/' );
            // Get color scheme css
            JHTML::_( 'stylesheet', $color.'.css', 'modules/mod_mmslideshow/skins/'.$skin.'/color/'.$color.'/' );
        endif;

        // include the cool stuff
        JHTML::_('behavior.mootools');
        if ( JApplication::getCfg( 'debug' ) && file_exists( JPATH_ROOT.DS.'modules/mod_mmslideshow/assets/js/icarousel.source.js' ) ) {
            JHTML::script( 'icarousel.source.js', 'modules/mod_mmslideshow/assets/js/' );
        } else {
            JHTML::script( 'icarousel.min.js', 'modules/mod_mmslideshow/assets/js/' );
        }

        if ( JApplication::getCfg( 'debug' ) && file_exists( JPATH_ROOT.DS.'modules/mod_mmslideshow/assets/js/mmslideshow.source.js' ) ) {
            JHTML::script( 'mmslideshow.source.js', 'modules/mod_mmslideshow/assets/js/' );
        } else {
            JHTML::script( 'mmslideshow.min.js', 'modules/mod_mmslideshow/assets/js/' );
        }

        // Initiate mmSlideshow vs iCarousel
        $document->addScriptDeclaration("
            window.addEvent('domready', function() {
                mmSlideShow".$module->id." = new mmSlideshow(".$module->id.", {
                    width: ".$slideshow_width.",
                    height: ".$slideshow_height.",
                    animationType: '".$animation_type."',
                    animationDirection: '".$animation_direction."',
                    animationTransition: '".$animation_transition."',
                    animationEase: '".$animation_ease."',
                    animationDuration: ".$animation_duration.",
                    rotateType: '".$rotate_type."',
                    rotateInterval: ".$rotate_interval.",
                    rotateOnMouseOver: '".$rotate_onmouseover."',
                    showPlayPause: ".$show_playpause."
                });
            });
        ");

        // Add some specific required CSS to make stuff work based on teh animation type (fade vs slide)
        if ( $animation_type == 'fade' ) {
            $css = '
                #mmSlideshow'.$module->id.'-wrapper { width: '.$slideshow_width.'px; }
                #mmSlideshow'.$module->id.' { position: relative; overflow: hidden; width: '.$slideshow_width.'px; height: '.$slideshow_height.'px; margin: 0; }
                #mmSlideshow'.$module->id.'-slides { position: relative; top: 0; margin-left: 0; }
                #mmSlideshow'.$module->id.' ul li { position: absolute; width: '.$slideshow_width.'px; height: '.$slideshow_height.'px; top: 0px; left: 0px; display: block; margin: 0; padding: 0; cursor: pointer; }
                #mmSlideshow'.$module->id.'-controls { width: '.$slideshow_width.'px; }
            ';
            //                 #mmSlideshow'.$module->id.'-controls { width: '.(($nr_thumbs * $thumb_width)+100).'px; }

            $document->addStyleDeclaration( $css );
        } else {
            if ( $animation_direction == 'left' ) {
                // left & right
                $width = (count( $images ) * $slideshow_width) * 3;
                $css = '
                    #mmSlideshow'.$module->id.'-wrapper { width: '.$slideshow_width.'px; }
                    #mmSlideshow'.$module->id.' { position: relative; overflow: hidden; width: '.$slideshow_width.'px; height: '.$slideshow_height.'px; margin: 0; }
                    #mmSlideshow'.$module->id.'-slides { position: absolute; top: 0; width: '.$width.'px; } /* margin-left: 0;*/
                    #mmSlideshow'.$module->id.'-slides, #mmSlideshow'.$module->id.' li { list-style: none !important; margin: 0 !important; padding: 0 !important; }
                    #mmSlideshow'.$module->id.' li { float: left; width: '.$slideshow_width.'px; height: '.$slideshow_height.'px; overflow: hidden; display: block; }
                ';
            } else {
                // Up & down
                $height = (count( $images ) * $slideshow_height) * 3;
                $css = '
                    #mmSlideshow'.$module->id.'-wrapper { width: '.$slideshow_width.'px;  }
                    #mmSlideshow'.$module->id.' { position: relative; overflow: hidden; width: '.$slideshow_width.'px; height: '.$slideshow_height.'px; margin: 0; }
                    #mmSlideshow'.$module->id.'-slides { position: absolute; top: 0; height: '.$height.'px; } /*  margin-left: 0;*/
                    #mmSlideshow'.$module->id.'-slides, #mmSlideshow'.$module->id.' li { list-style: none !important; margin: 0 !important; padding: 0 !important; }
                    #mmSlideshow'.$module->id.' li { float: left; width: '.$slideshow_width.'px; height: '.$slideshow_height.'px; overflow: hidden; display: block; }
                ';
            }
            $document->addStyleDeclaration( $css );
        }

        if ( !$show_playpause && !$show_previousnext ) {
            // hide controls all together
            $css = '
                #pause'.$module->id.' { display: none; }
                #play'.$module->id.' { display: none; }
            ';
            $document->addStyleDeclaration( $css );
        }

        if ( !$show_playpause ) {
            $css = '
                #pause'.$module->id.' { display: none; }
                #play'.$module->id.' { display: none; }
            ';
            $document->addStyleDeclaration( $css );
        }
        if ( !$show_previousnext ) {
            $css = '
                #mmSlideshow'.$module->id.'-previous { display: none; }
                #mmSlideshow'.$module->id.'-next { display: none; }
            ';
            $document->addStyleDeclaration( $css );
        }

        // Play & pause
        if ( $rotate_type == 'auto' )  $css = '#play'.$module->id.' { display: none; }';
        else $css = '#pause'.$module->id.'{ display: none; }';
        $document->addStyleDeclaration( $css );
    }
}
